package com.vendor.burn.utilitily;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.utilitily.JarUtility;
import com.vendor.burn.utilitily.ToolUtils;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.URL;
import java.util.ArrayList;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Platform;
import org.eclipse.osgi.service.datalocation.Location;

public class FileUtils {
  public static final int BUFFER_SIZE = 1024;
  
  public static boolean isExists(String filePath) {
    if (filePath == null)
      return false; 
    File file = new File(filePath);
    if (!file.exists())
      return false; 
    return true;
  }
  
  public static String toAbsolutePath(String filePath) {
    if (!ToolUtils.isCmdLine()) {
      Location location = Platform.getInstallLocation();
      if (location != null && filePath != null) {
        URL url = location.getURL();
        return url.getPath() + "/" + url.getPath();
      } 
    } else {
      String jarDir = JarUtility.getJarDir();
      if (jarDir != null) {
        if (!jarDir.endsWith(File.separator))
          jarDir = jarDir.concat(File.separator); 
        return jarDir + jarDir;
      } 
      return filePath;
    } 
    return null;
  }
  
  public static byte[] readAllBytes(String filePath) {
    ByteArrayOutputStream outStream = new ByteArrayOutputStream();
    InputStream inStream = null;
    byte[] buffer = new byte[1024];
    try {
      inStream = org.apache.commons.io.FileUtils.openInputStream(new File(filePath));
      int read = 0;
      while ((read = inStream.read(buffer)) != -1)
        outStream.write(buffer, 0, read); 
    } catch (IOException e) {
      return null;
    } finally {
      try {
        if (outStream != null)
          outStream.close(); 
      } catch (IOException iOException) {}
      try {
        if (inStream != null)
          inStream.close(); 
      } catch (IOException iOException) {}
    } 
    return outStream.toByteArray();
  }
  
  public static boolean copy(IProgressMonitor uiMonitor, File oldfile, File newFile) {
    BufferedInputStream inStream = null;
    BufferedOutputStream fs = null;
    try {
      if (oldfile.getCanonicalPath().equals(newFile.getCanonicalPath()))
        return true; 
      if (!checkFreeSpace(newFile.getParent(), oldfile.length()))
        return false; 
      int byteread = 0;
      if (oldfile.exists()) {
        inStream = new BufferedInputStream(org.apache.commons.io.FileUtils.openInputStream(oldfile));
        fs = new BufferedOutputStream(org.apache.commons.io.FileUtils.openOutputStream(newFile));
        byte[] buffer = new byte[4096];
        while ((byteread = inStream.read(buffer)) != -1 && (
          uiMonitor == null || !uiMonitor.isCanceled()))
          fs.write(buffer, 0, byteread); 
        fs.close();
        inStream.close();
      } 
    } catch (IOException e) {
      return false;
    } finally {
      try {
        if (fs != null)
          fs.close(); 
      } catch (IOException iOException) {}
      try {
        if (inStream != null)
          inStream.close(); 
      } catch (IOException iOException) {}
    } 
    return true;
  }
  
  public static StringBuilder readFromFile(String path) {
    StringBuilder strInfo = new StringBuilder();
    BufferedReader br = null;
    try {
      br = new BufferedReader(new InputStreamReader(new FileInputStream(path), "GBK"));
      String item = "";
      while ((item = br.readLine()) != null) {
        if (item.length() > 0) {
          String info = item;
          strInfo.append(info + "\r\n");
        } 
      } 
    } catch (FileNotFoundException fileNotFoundException) {
    
    } catch (IOException iOException) {
    
    } finally {
      if (br != null)
        try {
          br.close();
        } catch (IOException iOException) {} 
    } 
    return strInfo;
  }
  
  public static boolean deleteFile(File file) {
    if (file == null)
      return false; 
    if (!file.exists())
      return true; 
    long startTime = System.currentTimeMillis();
    long outTime = 5000L;
    while (!file.delete() && 
      System.currentTimeMillis() - startTime < outTime) {
      try {
        Thread.sleep(1L);
      } catch (InterruptedException interruptedException) {}
    } 
    if (file.exists())
      return false; 
    return true;
  }
  
  public static boolean checkFreeSpace(String directoryPath, long fileSize) {
    File fileDirectory = new File(directoryPath);
    if (fileDirectory.getFreeSpace() < fileSize)
      return false; 
    return true;
  }
  
  public static boolean isCreateNewFile(File newFile) {
    if (newFile.exists())
      deleteFile(newFile); 
    boolean isCreate = false;
    try {
      isCreate = newFile.createNewFile();
    } catch (IOException iOException) {}
    return isCreate;
  }
  
  public static ArrayList<String> readAllLines(String filePath) {
    ArrayList<String> result = new ArrayList<>();
    BufferedReader bReader = null;
    InputStreamReader isReader = null;
    InputStream inStream = null;
    try {
      inStream = new FileInputStream(filePath);
      isReader = new InputStreamReader(inStream, System.getProperty("file.encoding"));
      bReader = new BufferedReader(isReader);
      String line = null;
      while ((line = bReader.readLine()) != null)
        result.add(line); 
    } catch (IOException e) {
      return null;
    } finally {
      try {
        if (bReader != null)
          bReader.close(); 
      } catch (IOException e) {
        return null;
      } 
      try {
        if (isReader != null)
          isReader.close(); 
      } catch (IOException e) {
        return null;
      } 
      try {
        if (inStream != null)
          inStream.close(); 
      } catch (IOException e) {
        return null;
      } 
    } 
    return result;
  }
  
  public static void checkFilePath(File file) throws IOException {
    if (file.exists()) {
      if (file.isDirectory())
        throw new IOException("File '" + file + "' exists but is a directory"); 
      if (!file.canRead())
        throw new IOException("File '" + file + "' cannot be read"); 
    } 
  }
  
  public static boolean writeLines(String line, String filePath, String charset) {
    FileOutputStream outputStream = null;
    OutputStreamWriter streamWriter = null;
    BufferedWriter bufferedWriter = null;
    boolean isSuccess = true;
    try {
      outputStream = new FileOutputStream(filePath, true);
      streamWriter = new OutputStreamWriter(outputStream, charset);
      bufferedWriter = new BufferedWriter(streamWriter);
      bufferedWriter.append(line + line);
    } catch (IOException e) {
      isSuccess = false;
    } finally {
      try {
        if (bufferedWriter != null)
          bufferedWriter.close(); 
        if (streamWriter != null)
          streamWriter.close(); 
        if (outputStream != null)
          outputStream.close(); 
      } catch (IOException e) {
        isSuccess = false;
      } 
    } 
    return isSuccess;
  }
}
